[logback-dev] branch, master, updated. v0.9.18-4-g6b87197

added by portage for gitosis-gentoo git-noreply at pixie.qos.ch
Mon Dec 7 01:32:41 CET 2009


The branch, master has been updated
       via  6b87197e32713959bdebd4f315466e9466fd1ace (commit)
      from  859774c1848fe2f755efd12776a1ce2a05aa8c5f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://git.qos.ch/gitweb/?p=logback.git;a=commit;h=6b87197e32713959bdebd4f315466e9466fd1ace
http://github.com/ceki/logback/commit/6b87197e32713959bdebd4f315466e9466fd1ace

commit 6b87197e32713959bdebd4f315466e9466fd1ace
Author: Ceki Gulcu <ceki at rhino.localdomain>
Date:   Sun Dec 6 19:29:19 2009 -0500

    - Make ReconfigureOnChangeTest pass on Mac by taking into account the
    longer latency
    
    - Increase latency from 850ms to 950ms (this makes the tests pass
    quite consistently on Linux)

diff --git a/logback-core/src/test/java/ch/qos/logback/core/testUtil/Env.java b/logback-core/src/test/java/ch/qos/logback/core/testUtil/Env.java
index 00bccb9..bc7f55e 100644
--- a/logback-core/src/test/java/ch/qos/logback/core/testUtil/Env.java
+++ b/logback-core/src/test/java/ch/qos/logback/core/testUtil/Env.java
@@ -19,6 +19,10 @@ public class Env {
     return System.getProperty("os.name").indexOf("Windows") != -1;
   }
 
+  static public boolean isMac() {
+    return System.getProperty("os.name").indexOf("Mac") != -1;
+  }
+  
   static public boolean isLinux() {
     return System.getProperty("os.name").indexOf("Linux") != -1;
   }
diff --git a/logback-examples/.gitignore b/logback-examples/.gitignore
new file mode 100644
index 0000000..f1ff06d
--- /dev/null
+++ b/logback-examples/.gitignore
@@ -0,0 +1 @@
+lib/
\ No newline at end of file

-----------------------------------------------------------------------

Summary of changes:
 .../classic/turbo/ReconfigureOnChangeTest.java     |    6 +++---
 .../java/ch/qos/logback/core/testUtil/Env.java     |    4 ++++
 logback-examples/.gitignore                        |    1 +
 3 files changed, 8 insertions(+), 3 deletions(-)
 create mode 100644 logback-examples/.gitignore


hooks/post-receive
diff --git a/logback-classic/src/test/java/ch/qos/logback/classic/turbo/ReconfigureOnChangeTest.java b/logback-classic/src/test/java/ch/qos/logback/classic/turbo/ReconfigureOnChangeTest.java
index cff1fff..b3a80df 100644
--- a/logback-classic/src/test/java/ch/qos/logback/classic/turbo/ReconfigureOnChangeTest.java
+++ b/logback-classic/src/test/java/ch/qos/logback/classic/turbo/ReconfigureOnChangeTest.java
@@ -67,9 +67,9 @@ public class ReconfigureOnChangeTest {
 
   @Before
   public void setUp() {
-    // take into account propagation latency occurs on Linux
-    if (Env.isLinux()) {
-      sleepBetweenUpdates = 850;
+    // take into account propagation latency occurs on Linux or Mac
+    if (Env.isLinux() || Env.isMac()) {
+      sleepBetweenUpdates = 950;
       totalTestDuration = sleepBetweenUpdates * 5;
     } else {
       totalTestDuration = sleepBetweenUpdates * 10;
-- 
Logback: the generic, reliable, fast and flexible logging framework.


More information about the logback-dev mailing list